==> python-dateparser-1.0.0-2-any.pkg.tar.xz: usr/lib/python3.9/site-packages/dateparser/data/date_translation_data/lt.py <==
info = {
    "name": "lt",
    "date_order": "YMD",
    "january": [
        "sausis",
        "saus",
        "sausio"
    ],
    "february": [
        "vasaris",
        "vas",
        "vasario"
    ],
    "march": [
        "kovas",
        "kov",
        "kovo"
    ],
    "april": [
        "balandis",
        "bal",
        "balandžio"
    ],
    "may": [
        "gegužė",
        "geg",
        "gegužės"
    ],
    "june": [
        "birželis",
        "birž",
        "birželio"
    ],
    "july": [
        "liepa",
        "liep",
        "liepos"
    ],
    "august": [
        "rugpjūtis",
        "rugp",
        "rugpjūčio"
    ],
    "september": [
        "rugsėjis",
        "rugs",
        "rugsėjo"
    ],
    "october": [
        "spalis",
        "spal",
        "spalio"
    ],
    "november": [
        "lapkritis",
        "lapkr",
        "lapkričio"
    ],
    "december": [
        "gruodis",
        "gruod",
        "gruodžio"
    ],
    "monday": [
        "pirmadienis",
        "pr"
    ],
    "tuesday": [
        "antradienis",
        "an"
    ],
    "wednesday": [
        "trečiadienis",
        "tr"
    ],
    "thursday": [
        "ketvirtadienis",
        "kt"
    ],
    "friday": [
        "penktadienis",
        "pn"
    ],
    "saturday": [
        "šeštadienis",
        "št"
    ],
    "sunday": [
        "sekmadienis",
        "sk"
    ],
    "am": [
        "priešpiet"
    ],
    "pm": [
        "popiet"
    ],
    "year": [
        "metai",
        "m"
    ],
    "month": [
        "mėnuo",
        "mėn"
    ],
    "week": [
        "savaitė",
        "sav"
    ],
    "day": [
        "diena",
        "d"
    ],
    "hour": [
        "valanda",
        "val",
        "h"
    ],
    "minute": [
        "minutė",
        "min"
    ],
    "second": [
        "sekundė",
        "sek",
        "s"
    ],
    "relative-type": {
        "1 year ago": [
            "praėjusiais metais"
        ],
        "0 year ago": [
            "šiais metais"
        ],
        "in 1 year": [
            "kitais metais"
        ],
        "1 month ago": [
            "praėjusį mėnesį"
        ],
        "0 month ago": [
            "šį mėnesį"
        ],
        "in 1 month": [
            "kitą mėnesį"
        ],
        "1 week ago": [
            "praėjusią savaitę"
        ],
        "0 week ago": [
            "šią savaitę"
        ],
        "in 1 week": [
            "kitą savaitę"
        ],
        "1 day ago": [
            "vakar"
        ],
        "0 day ago": [
            "šiandien"
        ],
        "in 1 day": [
            "rytoj"
        ],
        "0 hour ago": [
            "šią valandą"
        ],
        "0 minute ago": [
            "šią minutę"
        ],
        "0 second ago": [
            "dabar"
        ]
    },
    "relative-type-regex": {
        "in \\1 year": [
            "po (\\d+) metų",
            "po (\\d+) m"
        ],
        "\\1 year ago": [
            "prieš (\\d+) metus",
            "prieš (\\d+) metų",
            "prieš (\\d+) m"
        ],
        "in \\1 month": [
            "po (\\d+) mėnesio",
            "po (\\d+) mėnesių",
            "po (\\d+) mėn"
        ],
        "\\1 month ago": [
            "prieš (\\d+) mėnesį",
            "prieš (\\d+) mėnesių",
            "prieš (\\d+) mėn"
        ],
        "in \\1 week": [
            "po (\\d+) savaitės",
            "po (\\d+) savaičių",
            "po (\\d+) sav"
        ],
        "\\1 week ago": [
            "prieš (\\d+) savaitę",
            "prieš (\\d+) savaičių",
            "prieš (\\d+) sav"
        ],
        "in \\1 day": [
            "po (\\d+) dienos",
            "po (\\d+) dienų",
            "po (\\d+) d"
        ],
        "\\1 day ago": [
            "prieš (\\d+) dieną",
            "prieš (\\d+) dienų",
            "prieš (\\d+) d"
        ],
        "in \\1 hour": [
            "po (\\d+) valandos",
            "po (\\d+) valandų",
            "po (\\d+) val"
        ],
        "\\1 hour ago": [
            "prieš (\\d+) valandą",
            "prieš (\\d+) valandų",
            "prieš (\\d+) val"
        ],
        "in \\1 minute": [
            "po (\\d+) minutės",
            "po (\\d+) minučių",
            "po (\\d+) min"
        ],
        "\\1 minute ago": [
            "prieš (\\d+) minutę",
            "prieš (\\d+) minučių",
            "prieš (\\d+) min"
        ],
        "in \\1 second": [
            "po (\\d+) sekundės",
            "po (\\d+) sekundžių",
            "po (\\d+) sek",
            "po (\\d+) s"
        ],
        "\\1 second ago": [
            "prieš (\\d+) sekundę",
            "prieš (\\d+) sekundžių",
            "prieš (\\d+) sek",
            "prieš (\\d+) s"
        ]
    },
    "locale_specific": {},
    "skip": [
        " ",
        ".",
        ",",
        ";",
        "-",
        "/",
        "'",
        "|",
        "@",
        "[",
        "]",
        "，"
    ]
}

==> python-dateparser-1.1.1-1-any.pkg.tar.xz: usr/lib/python3.10/site-packages/dateparser/data/date_translation_data/lt.py <==
info = {
    "name": "lt",
    "date_order": "YMD",
    "january": [
        "saus",
        "sausio",
        "sausis"
    ],
    "february": [
        "vas",
        "vasario",
        "vasaris"
    ],
    "march": [
        "kov",
        "kovas",
        "kovo"
    ],
    "april": [
        "bal",
        "balandis",
        "balandžio"
    ],
    "may": [
        "geg",
        "gegužė",
        "gegužės"
    ],
    "june": [
        "birž",
        "birželio",
        "birželis"
    ],
    "july": [
        "liep",
        "liepa",
        "liepos"
    ],
    "august": [
        "rugp",
        "rugpjūtis",
        "rugpjūčio"
    ],
    "september": [
        "rugs",
        "rugsėjis",
        "rugsėjo"
    ],
    "october": [
        "spal",
        "spalio",
        "spalis"
    ],
    "november": [
        "lapkr",
        "lapkritis",
        "lapkričio"
    ],
    "december": [
        "gruod",
        "gruodis",
        "gruodžio"
    ],
    "monday": [
        "pirmadienis",
        "pr"
    ],
    "tuesday": [
        "an",
        "antradienis"
    ],
    "wednesday": [
        "tr",
        "trečiadienis"
    ],
    "thursday": [
        "ketvirtadienis",
        "kt"
    ],
    "friday": [
        "penktadienis",
        "pn"
    ],
    "saturday": [
        "šeštadienis",
        "št"
    ],
    "sunday": [
        "sekmadienis",
        "sk"
    ],
    "am": [
        "priešpiet"
    ],
    "pm": [
        "popiet"
    ],
    "year": [
        "m",
        "metai"
    ],
    "month": [
        "mėn",
        "mėnuo"
    ],
    "week": [
        "sav",
        "savaitė"
    ],
    "day": [
        "d",
        "diena"
    ],
    "hour": [
        "h",
        "val",
        "valanda"
    ],
    "minute": [
        "min",
        "minutė"
    ],
    "second": [
        "s",
        "sek",
        "sekundė"
    ],
    "relative-type": {
        "0 day ago": [
            "šiandien"
        ],
        "0 hour ago": [
            "šią valandą"
        ],
        "0 minute ago": [
            "šią minutę"
        ],
        "0 month ago": [
            "šį mėnesį"
        ],
        "0 second ago": [
            "dabar"
        ],
        "0 week ago": [
            "šią savaitę"
        ],
        "0 year ago": [
            "šiais metais"
        ],
        "1 day ago": [
            "vakar"
        ],
        "1 month ago": [
            "praėjusį mėnesį"
        ],
        "1 week ago": [
            "praėjusią savaitę"
        ],
        "1 year ago": [
            "praėjusiais metais"
        ],
        "in 1 day": [
            "rytoj"
        ],
        "in 1 month": [
            "kitą mėnesį"
        ],
        "in 1 week": [
            "kitą savaitę"
        ],
        "in 1 year": [
            "kitais metais"
        ]
    },
    "relative-type-regex": {
        "\\1 day ago": [
            "prieš (\\d+) d",
            "prieš (\\d+) dieną",
            "prieš (\\d+) dienų"
        ],
        "\\1 hour ago": [
            "prieš (\\d+) val",
            "prieš (\\d+) valandą",
            "prieš (\\d+) valandų"
        ],
        "\\1 minute ago": [
            "prieš (\\d+) min",
            "prieš (\\d+) minutę",
            "prieš (\\d+) minučių"
        ],
        "\\1 month ago": [
            "prieš (\\d+) mėn",
            "prieš (\\d+) mėnesių",
            "prieš (\\d+) mėnesį"
        ],
        "\\1 second ago": [
            "prieš (\\d+) s",
            "prieš (\\d+) sek",
            "prieš (\\d+) sekundę",
            "prieš (\\d+) sekundžių"
        ],
        "\\1 week ago": [
            "prieš (\\d+) sav",
            "prieš (\\d+) savaitę",
            "prieš (\\d+) savaičių"
        ],
        "\\1 year ago": [
            "prieš (\\d+) m",
            "prieš (\\d+) metus",
            "prieš (\\d+) metų"
        ],
        "in \\1 day": [
            "po (\\d+) d",
            "po (\\d+) dienos",
            "po (\\d+) dienų"
        ],
        "in \\1 hour": [
            "po (\\d+) val",
            "po (\\d+) valandos",
            "po (\\d+) valandų"
        ],
        "in \\1 minute": [
            "po (\\d+) min",
            "po (\\d+) minutės",
            "po (\\d+) minučių"
        ],
        "in \\1 month": [
            "po (\\d+) mėn",
            "po (\\d+) mėnesio",
            "po (\\d+) mėnesių"
        ],
        "in \\1 second": [
            "po (\\d+) s",
            "po (\\d+) sek",
            "po (\\d+) sekundės",
            "po (\\d+) sekundžių"
        ],
        "in \\1 week": [
            "po (\\d+) sav",
            "po (\\d+) savaitės",
            "po (\\d+) savaičių"
        ],
        "in \\1 year": [
            "po (\\d+) m",
            "po (\\d+) metų"
        ]
    },
    "locale_specific": {},
    "skip": [
        " ",
        "'",
        ",",
        "-",
        ".",
        "/",
        ";",
        "@",
        "[",
        "]",
        "|",
        "，"
    ]
}
